function sOut = convert_CUSTOM_GAZEDATA(doWhat,setts)
% convert_CUSTOM_GAZEDATA Customizes GAZEDATA convertion.
%
%  This DEMO script shows how to customize a gazedata converter.
%
%  See DESC.m for info.
%
%  Elio Sjak-Shie, June 2019
%--------------------------------------------------------------------------

%% Code:

switch doWhat
    
    %----------------------------------------------------------------------
    case 'getConverterInfo'
        % Returns info about the converter.
        %------------------------------------------------------------------
        
        % Run the default converter:
        sOut = convert_GAZEDATA(doWhat);
        
        
        %==================================================================
        % Customize the Converter info here.
        %
        %  Always at least modify the converter name so that it can be
        %  differentiated from the standard converter. Also, use this
        %  section to add, remove or modify converter set up options.
        %==================================================================
        
        % Include a description of the converter
        sOut.name = 'Custom GAZEDATA Demo';
        sOut.desc = 'Same as GAZEDATA, but customizable!';
        
        
        %------------------------------------------------------------------
    case 'setupConverter'
        % Sets up the Converter.
        %------------------------------------------------------------------
        
        
        % Run the default converter:
        sOut = convert_GAZEDATA(doWhat,setts);
        
        
        %==================================================================
        % Setup the Converter here.
        %
        %  Use this section to add custom converter options, if desired.
        %==================================================================
        
        
        %------------------------------------------------------------------
    case 'getFileInfo'
        % Returns metadata about a raw file.
        %------------------------------------------------------------------

        
        % Run the default converter:
        sOut = convert_GAZEDATA(doWhat,setts);
        
        
        %==================================================================
        % Customize the file info here.
        %
        %  This is generally not necessary if basing the custom converter
        %  on a pre-existing converter, as the raw data is not edited.
        %==================================================================

        
        %------------------------------------------------------------------
    case {'convertFile' 'getData'}
        % Import data from a raw file and save it as a PhysioData file, or
        % return the data.
        %------------------------------------------------------------------
        
        
        % Run the default converter, but have it return the data, not save
        % it:
        sOut = convert_GAZEDATA('getData',setts);
        
        
        %==================================================================
        % Modify the data here.
        %==================================================================
        
        
        % If the data was requested, return, otherwise, save it:
        switch doWhat
            case 'getData'
                return
            case 'convertFile'
                physDatObj      = PhysioDataFileModel();
                physDatObj.data = sOut;
                physDatObj.saveToFile(setts.newFileName,setts.doAppend);
        end
        
    otherwise
        error('Wrong flag')
end


end


