function acqGetCB(status, a, b, c, d)
%acqGetCB Modifiable callback function for a running acqGet mex file. This
%function is called intermittently to print stuff to the console.
% 
% The callback function is called using a 'status' argument, which defines
% its behavior, and variable input arguments (varargin) with the necessary
% info.
%
% status(arguments):
%
%         openingFile()
%         openedFile(version, mpDevID, numChannels, sampleRate)
%         doingChan(curChanIter,curChanIndx,totalChans)
%         doneChan(curChanIter,curChanIndx,totalChans)
%         doingMarker(totalMarkers)
%         doneMarker(curMarkerIter)
%         complete()
%
%  Elio Sjak-Shie, 2017.
%
%--------------------------------------------------------------------------

drawnow;
printToConsole = false;
if ~printToConsole
    return
end
switch status
    
    case 'openingFile'
        % Called when a file is about to be opened.
        
        fprintf('\nacqGet: Opening File...\n');
        
    case 'openedFile'
        % Called when a file has been successfully opened.
        
        fprintf(['acqGet: File opened (v: %i'...
            ', MP-ID: %i, nChannels: %i, fs: %i Hz).\n'], a,b,c,d); 
        
    case 'doingChan'
        % Called when extracting data from a channel.
        
        fprintf('acqGet: Processing channel %i (indx = %i) of %i ...', a, b, c);
        
    case 'doneChan'
        % Called when done extracting data from a channel.
        
        fprintf(' done.\n');
        
    case 'doingMarker' 
        % Called when processing a marker.
        
        fprintf('acqGet: File contains %i markers.\n', a);
        
    case 'doneMarker' 
        % Called when done processing the markers.
                
        fprintf('acqGet: Done processing marker %i.\n', a);
        
    case 'complete'
        % Called when done.
        
        fprintf('acqGet: Done.\n\n')
        
        %** Update GUI**
        
    otherwise
end
end