function varargout = convert_LIBC_ACHIEVA_MRI(doWhat,setts)
% Converts physlog files from the MRI scanner.
%
% Elio Sjak-Shie, June 2019.
%--------------------------------------------------------------------------


switch doWhat
    
    case 'getConverterInfo'
        % Returns info about the converter.
        
        % Include a description of the converter
        sOut.name   = 'LIBC Achieva MRI';
        sOut.desc   = ['Converts physiology log files from the'...
            ' LIBC''s Philips Achieva 3T MRI scanner'];
        
        % Set the out and return:
        varargout{1} = sOut;
        return
        
    case 'setupConverter'
        
        % Return the extension (no special options here):
        sOut.ext    = 'log';
        
        % Set the out and return:
        varargout{1} = sOut;
        
    case 'getFileInfo'
        % Returns info about a single file.
        
        % This function should return an error if the file could not be
        % read, or is incorrect; e.g., if the file has the ext but is not
        % the correct version!
        sOut.error ='';
        
        try
            
            rawFileName = setts.rawFileName;
            assert(exist(rawFileName,'file')==2 ...
                ,'The raw file is missing.');
            [data] = readPhysLog(rawFileName);
            
            % Make output struct:
            sOut.signals   = rmfield(data.signals,'channels');
            sOut.signals.L = numel(data.signals.channels{1});
            
            % Add markers:
            if isfield(data,'labels')
                
                
                % Only the count is used by the file converter, but lets
                % leave the labels in anyways:
                sOut.labels       = data.labels;
                sOut.labels.count = numel(sOut.labels.t);
                
            end
        catch ME
            error('Error running readPhysLog (%s).',ME.message);
        end
        
        % Set the out and return:
        varargout{1} = sOut;
        return
        
        
    case {'convertFile' 'getData'}
        % In the convertFile case, get the data first and save it.
        
        
        try
            
            % Get data:
            rawFileName = setts.rawFileName;
            assert(exist(rawFileName,'file')==2 ...
                ,'The raw file is missing.');
            [data] = readPhysLog(rawFileName);
            
            % Make a PhysioDataFileModel object:
            physDatObj = PhysioDataFileModel();
            
            
            % Remove unrequested data:
            for F = fieldnames(data.signals)'
                if iscell(data.signals.(F{1}))
                    data.signals.(F{1}) ...
                        = data.signals.(F{1})(setts.signalsToExtract);
                end
            end
            
            physDatObj.data = data;
            physDatObj.genPhysioDataInfo(setts.rawFileName);
            
            % Save or return data:
            switch doWhat
                case 'convertFile'
                    physDatObj.saveToFile(setts.newFileName,setts.doAppend);
                    return
                case 'getData'
                    varargout{1} = struct(physDatObj);
                    return
            end
            
        catch ME
            error('Error running readPhysLog (%s).',ME.message);
        end
        
        
    otherwise
        error('wrong flag')
end

end

