function [labels,eventSections] = listAnalysis(t_ms,listIn,mergeMissing)
%listAnalysis Analyzes events in a numeric, cellstr or categorical list.
%
%   Syntax:
%    [labels,sections] = listAnalysis(t_ms,listIn[,mergeMissing])
%
%    t_ms - The time vector.
%
%    listIn - The list to analyze.
%
%    mergeMissing - (Optional) Flag indicating if missing or empty rows
%    should be deleted priot to analysis. Setting this to true effectively
%    slices the sections at parts that are empty/missing. If omitted, it
%    defaults to false;
%
%    labels - The results returned as a labels struct.
%
%    eventSections - The results returned as a eventSections struct.
%
%--------------------------------------------------------------------------
%
%   Elio Sjak-Shie, 2017.
%    https://physiodatatoolbox.leidenuniv.nl/
%
%--------------------------------------------------------------------------



%--------------------------------------------------------------------------
keyboard;
% THIS FUNCTION IS DEPRICATED AS OF TOOLBOX VERSION 0.5. Use analyzeList()
% instead.
%--------------------------------------------------------------------------


if nargin < 3
    mergeMissing = false;
end

% Check input:
assert(size(listIn,2)==1,'sectionCode must be a 1 column vector.');
assert(size(t_ms,2)==1,'t_ms must be a 1 column vector.');
assert(size(listIn,1)==size(t_ms,1)...
    ,'sectionCode and t_ms must have the same number of columns.');
assert(all(diff(t_ms)>0)...
    ,'t_ms must be strictly monotonically increasing.');

% Transform data in into a categorical array:
sectionCode = categorical(listIn);

% If the mergeMissing flag is set to true, pre-remove rows without
% information (essentially merging the rows):
if mergeMissing
    
    %TODO: Fix usage of ismissing below. This will crash in older versions
    % of MATLAB.
    
    % Identify the rows without labels, and delete them:
    noLabels = ismissing(sectionCode);
    sectionCode(noLabels) = [];
    t_ms(noLabels)        = [];
    
end

% Transform the categorical array into a double array so that the
% getMarkers function can be used for analysis. Prevent the function from
% removing the leading zero by padding it with a zero, of which the index
% is later subtracted:
secID               = double(sectionCode);
secID(isnan(secID)) = 0;
Markers             = getMarkers([0;secID;0]);
Markers(:,[2 3])    = Markers(:,[2 3]) - 1;

% Generate the names:
uniqueSegementNames = categories(sectionCode);
segmentNames        = uniqueSegementNames(Markers(:,1));
if isnumeric(listIn)
    segmentNames = strcat({'Trial_'},segmentNames);
end

% Generate the times:
segmentStart_ms = t_ms(Markers(:,2));
segmentEnd_ms   = t_ms(Markers(:,3)) + 0.1;

% Generate the labels format:
startEventNames = strcat({'Start_'},segmentNames);
endEventNames   = strcat({'End_'},segmentNames);
eventNames      = [startEventNames endEventNames]';
labels.name     = eventNames(:);
StartEndTimes   = [segmentStart_ms segmentEnd_ms]';
labels.t_ms     = StartEndTimes(:);

% Generate the sections:
eventSections = struct();
uniqueEvtNames = unique(segmentNames,'stable');
for curEvtIndx = 1 : numel(unique(segmentNames(:)'))
    curName = uniqueEvtNames{curEvtIndx};
    curRows  = strcmp(segmentNames,curName);
    eventSections(curEvtIndx).name  = curName;
    eventSections(curEvtIndx).hit   = [segmentStart_ms(curRows) ...
        segmentEnd_ms(curRows)];
    eventSections(curEvtIndx).desc = ['Section demarked by label ' ...
        curName '.']; 
end
end


%% Function Tests:

function testMe() %#ok<DEFNU>

% Make string sections, no mergin:
secCodeAndTimes = {...
    1  'A';...
    2  'A';...
    3  'A';...
    4  '';...
    5  '';...
    6  'A';...
    7  'A';...
    8  'B';...
    9  'B';...
    10 '';...
    11 'C';...
    12 'C';...
    13 'C';...
    14 'C';...
    15 'A';...
    ...
    20 '';...
    30 '';...
    35 '';...
    40 'A';...
    41 'A';...
    };
secCode  = secCodeAndTimes(:,2);
sec_t_ms = [secCodeAndTimes{:,1}]';
[labels,eventSections] = listAnalysis(sec_t_ms,secCode,false);
disp(' ');
disp(' labels:')
disp([num2cell(labels.t_ms) labels.name]);

disp(' eventSections:')
arrayfun(@(s) disp([{[s.name ':'] ''}; num2cell(s.hit)]),eventSections)


end





