function strOut = listToString(listIn,quotes,emptyStr,andStr)
% Converts cellstring list into a string.
%
%   strOut = listToString(listIn)
%
%   e.g.: listToString({'One' 'Two' 'Tres'}) = '"One", "Two" and "Tres"'
%
%--------------------------------------------------------------------------
%   Part of the PhysioData Toolbox.
%    Elio Sjak-Shie, Faculty of Social Sciences,
%     Leiden University, 2016.
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%   Changelog:
%
%   Oct-2016 -- Elio:
%        > Wrote first version.
%
%   Aug-2017 -- Elio:
%        > Second and third arguments now allows user specified quote and
%        empty marks.
%
%   July-2019 -- Elio:
%        > Fourth argument now allows user specified "and".
%
%--------------------------------------------------------------------------


% What quotes to use:
if nargin<2
    quotes = '"';
end

if nargin<3
    emptyStr = 'none';
end

if nargin<4
    andStr = ' and ';
end

% Check inputs:
assert(iscell(listIn))
listIn(cellfun(@isempty,listIn)) = [];
if isempty(listIn)
    strOut = emptyStr;
    return;
end
assert(min(size(listIn))==1)
if size(listIn,1)~=1
    listIn = listIn';
end

% Reformat list:
if length(listIn)>1
    listIn(2,:)     = listIn(1,:);
    listIn([1 3],:) = {quotes};
    listIn(4,:)     = {', '};
    listIn          = listIn(1:end-1);
    listIn(end-3)   = {andStr};
    strOut          = horzcat(listIn{:});
else
    strOut          = [quotes listIn{1} quotes];
end

end