function dataOut = splitDataIntoEpochs(dataIn,epochsIn)
%splitDataIntoEpochs Splits a single data field into multiple fields based
%on epochs.

epochCount = size(epochsIn,1);

if epochCount==0
    dataOut = struct.empty;
else
    dataOut = struct();
end
for epochIndx = 1:epochCount
    
    if ~isempty(epochsIn.startTime(epochIndx))...
            &&~isempty(epochsIn.endTime(epochIndx))...
            &&isempty(epochsIn.epochError{epochIndx})
        
        % Fill data out metadata fields:
        dataOut.(char(epochsIn.epochName(epochIndx))) ...
            = rmfield(dataIn,{'channels' 't'});
        
        % get inside-epoch logicals:
        inCurEpoch = dataIn.t>=epochsIn.startTime(epochIndx)...
            &dataIn.t<epochsIn.endTime(epochIndx);
        
        % Fill in rest:
        dataOut.(char(epochsIn.epochName(epochIndx))).t...
            = dataIn.t(inCurEpoch);
        dataOut.(char(epochsIn.epochName(epochIndx))).channels...
            = cellfun(@(s) s(inCurEpoch,:),dataIn.channels...
            ,'UniformOutput',false);
    else
        dataOut.(char(epochsIn.epochName(epochIndx))) = [];
    end

end
end