function sampleOut = time2sample(timeIn,fs)
%time2sample Converts a timestamp to a samplenumber.
%
%  sampleOut = time2sample(timeIn,fs)
%
% This function converts a timestamp to a samplenumber, given a sampling
% frequency fs. The function assumes equadistant spacings of 1/fs. An error
% is thrown if the time does not seem to correspond to a sample number;
% i.e., a precision of 5 digits to the right of the decimal point is
% required for convertion.
%
% This represents the time <-> sample convention used by the Toolbox.
% See also timeVector() and sample2time();
%
% Elio Sjak-Shie, 2018
%--------------------------------------------------------------------------

% Convert from time to sample:
sampleOut = round((timeIn+(1/fs)).*fs,5);

% Throw an error if the given time does not correspond to any sample number
% integer (even after the precision correction performed above):
assert(~any(rem(sampleOut,1)>0),'Precision error!');

end
